# Intro
This is a command tool like linux command `pwd` but stronger.  


It's really efficient.  

When you want to copy a absolute path of some file in your shell, you have to use pwd and then append the file  name, and select it with your mouse or use `control + c`, but now, just use abspath 
*filename* and it will copy the absolute path to your clipboard.   

This just save you 3 seconds at lease per operation.  

# Requirements
just require python3.6+ and a pip package `pyperclip`.

# Usage  


You can use the command `abspath ` without param to copy the current directory path or `abspath file_or_dir_in_this directory` to copy the full path to your clipbord.  
Just so easy and enjoy it!  

# Maintainer  
email: notfresh@foxmail.com  
github: github.com/notfresh  



